/*********************************************************************
 *
 *                Microchip C18 Firmware - RS-485 network
 *
 *********************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18F4520
 * Compiler:        C18
 * Company:         Lakeview Research LLC (www.Lvr.com)
 *
 * Software License Agreement
 *
 * Licensor grants any person obtaining a copy of this software ("You") 
 * a worldwide, royalty-free, non-exclusive license, for the duration of 
 * the copyright, free of charge, to store and execute the Software in a 
 * computer system and to incorporate the Software or any portion of it 
 * in computer programs You write.   

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Jan Axelson           10/19/07   	
 ********************************************************************/

/** I N C L U D E S **********************************************************/

#include <p18cxxx.h>
#include <usart.h>                  
#include "io_cfg.h"                                              
#include "system\typedefs.h"  
#include "user\user_rs485.h"       

/** V A R I A B L E S ********************************************************/

#pragma udata

/** P R I V A T E  P R O T O T Y P E S ***************************************/


/** V E C T O R  R E M A P P I N G *******************************************/

extern void _startup (void);        // See c018i.c in your C18 compiler dir
#pragma code _RESET_INTERRUPT_VECTOR = 0x000800

void _reset (void)
{
    _asm goto _startup _endasm
}
#pragma code

/** D E C L A R A T I O N S **************************************************/

#pragma code

/******************************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *****************************************************************************/
void main(void)
{
    
 	ADCON1 |= 0x0F;                 // Default all pins to digital

	TRISBbits.TRISB0 = 0;
	TRISBbits.TRISB1 = 0;
	TRISBbits.TRISB2 = 0;
	TRISBbits.TRISB3 = 0;

	PORTBbits.RB0 = 0;
	PORTBbits.RB1 = 0;
	PORTBbits.RB2 = 0;
	PORTBbits.RB3 = 0;

	configure_serial_port();
	configure_command_response();

    while(1)
    {
		// Application-specific tasks.
	
		serial_communications();
		
		// Add other tasks here.
	}
}
/** EOF main.c ***************************************************************/
